@@ -9,12 +9,14 @@ __all__ = ["CBPiActor",
            "parameters",
            "background_task",
            "CBPiKettleLogic",
+           "CBPiFermenterLogic",
            "CBPiException",
            "KettleException",
            "SensorException",
            "ActorException",
            "CBPiSensor",
-           "CBPiStep"]
+           "CBPiStep",
+           "CBPiFermentationStep"]
 
 from cbpi.api.actor import *
 from cbpi.api.sensor import *
@@ -22,5 +24,6 @@ from cbpi.api.extension import *
 from cbpi.api.property import *
 from cbpi.api.decorator import *
 from cbpi.api.kettle_logic import *
+from cbpi.api.fermenter_logic import *
 from cbpi.api.step import *
 from cbpi.api.exceptions import *
\ No newline at end of file
