@@ -2,49 +2,67 @@
 import asyncio
 from aiohttp import web
 from cbpi.api import *
-
+import time
+from datetime import datetime
 import re
-import random
-
+import logging
+from cbpi.api.dataclasses import NotificationAction, NotificationType
 
 cache = {}
 
-
+@parameters([Property.Text(label="Key", configurable=True, description="Http Key"),
+             Property.Number(label="Timeout", configurable="True",unit="sec",description="Timeout in seconds to send notification (default:60 | deactivated: 0)")
+])
 class HTTPSensor(CBPiSensor):
+    def __init__(self, cbpi, id, props):
+        super(HTTPSensor, self).__init__(cbpi, id, props)
+        self.running = True
+        self.value = 0
+        self.timeout=int(self.props.get("Timeout", 60))
+        self.starttime = time.time()
+        self.notificationsend = False
+        self.nextchecktime=self.starttime+self.timeout
+        self.sensor=self.get_sensor(self.id)
+        self.lastdata=time.time()
 
-    # Custom Properties which will can be configured by the user
-
-    key = Property.Text(label="Key", configurable=True)
-
-    def init(self):
-        super().init()
-
-        self.state = True
-
-    def get_state(self):
-        return self.state
-
-    def get_value(self):
-
-        return self.value
-
-    def stop(self):
+    async def Confirm(self, **kwargs):
+        self.nextchecktime = time.time() + self.timeout
+        self.notificationsend = False
         pass
 
-    async def run(self, cbpi):
-        self.value = 0
-        while True:
+    async def message(self):
+        target_timestring= datetime.fromtimestamp(self.lastdata)
+        self.cbpi.notify("HTTPSensor Timeout", "Sensor '" + str(self.sensor.name) + "' did not respond.  Last data received: "+target_timestring.strftime("%D %H:%M"), NotificationType.WARNING, action=[NotificationAction("OK", self.Confirm)])
+        pass
+
+    async def run(self):
+        '''
+        This method is executed asynchronousely 
+        In this example the code is executed every second
+        '''
+        while self.running is True:
+            if self.timeout !=0:
+                currenttime=time.time()            
+                if currenttime > self.nextchecktime and self.notificationsend == False:   
+                    await self.message()
+                    self.notificationsend=True
+            try:
+                cache_value = cache.pop(self.props.get("Key"), None)
+                if cache_value is not None:
+                    self.value = float(cache_value)
+                    self.push_update(self.value)
+                    if self.timeout !=0:
+                        self.nextchecktime = currenttime + self.timeout
+                        self.notificationsend = False
+                        self.lastdata=time.time()
+            except Exception as e:
+                logging.error(e)
+                pass
             await asyncio.sleep(1)
 
-            try:
-                value = cache.pop(self.key, None)
-
-                if value is not None:
-                    self.log_data(value)
-                    await cbpi.bus.fire("sensor/%s/data" % self.id, value=value)
-            except Exception as e:
-                print(e)
-                pass
+    def get_state(self):
+        # return the current state of the sensor
+        return dict(value=self.value)
 
 class HTTPSensorEndpoint(CBPiExtension):
 
@@ -96,7 +114,7 @@ class HTTPSensorEndpoint(CBPiExtension):
         if self.pattern_check.match(value) is None:
             return web.json_response(status=422, data={'error': "Data not matching pattern ^[a-zA-Z0-9,.]{0,10}$"})
 
-        print("HTTP SENSOR ", key, value)
+        
         cache[key] = value
 
         return web.Response(status=204)
