@@ -1,7 +1,9 @@
+from cbpi.utils.encoder import ComplexEncoder
 from aiohttp import web
 from cbpi.utils.utils import json_dumps
 from cbpi.api import request_mapping
-
+import os
+import json
 class LogHttpEndpoints:
 
     def __init__(self,cbpi):
@@ -82,7 +84,7 @@ class LogHttpEndpoints:
         )
         await response.prepare(request)
         log_name = request.match_info['name']
-        with open('./logs/%s.zip' % log_name, 'rb') as file:
+        with open(os.path.join(self.cbpi.logsFolderPath, '%s.zip' % log_name), 'rb') as file:
             for line in file.readlines():
                 await response.write(line)
 
@@ -135,12 +137,12 @@ class LogHttpEndpoints:
                 description: successful operation.
         """
         log_name = request.match_info['name']
-        print(log_name)
+        
         data = self.cbpi.log.get_logfile_names(log_name)
         return web.json_response(data, dumps=json_dumps)
 
     @request_mapping(path="/{name}", method="GET", auth_required=False)
-    async def delete_log(self, request):
+    async def get_log(self, request):
         """
         ---
         description: delete log data for sensor
@@ -163,19 +165,81 @@ class LogHttpEndpoints:
         data = await self.cbpi.log.get_data(log_name)
         return web.json_response(data, dumps=json_dumps)
 
+
+    @request_mapping(path="/", method="POST", auth_required=False)
+    async def get_log2(self, request):
+        """
+        ---
+        description: delete log data for sensor
+        tags:
+        - Log
+        parameters:
+        - in: body
+          name: body
+          description: Sensor Ids
+          required: true
+          schema:
+            type: array
+            items:
+              type: string
+        produces:
+        - application/json
+        responses:
+            "200":
+                description: successful operation.
+        """
+        data = await request.json()
+        return web.json_response(await self.cbpi.log.get_data2(data), dumps=json_dumps)
+
+
     @request_mapping(path="/{name}", method="DELETE", auth_required=False)
-    async def delete_all_logs(self, request):
+    async def clear_log(self, request):
         """
         ---
         description: Get log data for sensor
         tags:
         - Log
         parameters:
-
+        - name: "name"
+          in: "path"
+          description: "Sensor ID"
+          required: true
+          type: "integer"
+          format: "int64"
         responses:
             "204":
                 description: successful operation.
         """
         log_name = request.match_info['name']
-        await self.cbpi.log.clear_logs(log_name)
-        return web.Response(status=204)
\ No newline at end of file
+        self.cbpi.log.clear_log(log_name)
+        return web.Response(status=204)
+
+    @request_mapping(path="/logs", method="POST", auth_required=False)
+    async def get_logs(self, request):
+        """
+        ---
+        description: Get Logs
+        tags:
+        - Log
+        parameters:
+        - in: body
+          name: body
+          description: Sensor Ids
+          required: true
+          schema:
+            type: array
+            items:
+              type: string
+        produces:
+        - application/json
+        responses:
+            "200":
+                description: successful operation.
+        """
+        data = await request.json()
+        
+        result = await self.cbpi.log.get_data(data)
+        #print("JSON")
+        #print(json.dumps(result, cls=ComplexEncoder))
+        #print("JSON----")
+        return web.json_response(result, dumps=json_dumps)
